Introduction
============

Registration of formalize_ into Plone's resource registries (js&css).

Credits
=======

Companies
---------

|makinacom|_

  * `Planet Makina-Corpus <http://www.makina-corpus.org>`_
  * `Contact Makina-Corpus <mailto:python@makina-corpus.org>`_

Authors

  - JeanMichel FRANCOIS aka toutpt <toutpt@gmail.com>


.. |makinacom| image:: http://depot.makina-corpus.org/public/logo.gif
.. _makinacom:  http://www.makina-corpus.com
.. _formalize: http://formalize.me/

